OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Načítání náhledu…",
    "Admin" : "Správa",
    "Saved" : "Uloženo",
    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
    "Error uploading the file" : "Chyba při nahrávání souboru",
    "Name cannot be empty" : "Je třeba zadat název",
    "The given name is too long" : "Zadaný název je příliš dlouhý",
    "The given web address is too long" : "Zadaná webová adresa je příliš dlouhá",
    "The given web address is not a valid URL" : "Zadaná webová adresa není platné URL",
    "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platné URL",
    "The given privacy policy address is too long" : "Daná adresa zásad ochrany osobních údajů je příliš dlouhá",
    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platné URL",
    "The given slogan is too long" : "Daný slogan je příliš dlouhý",
    "The given color is invalid" : "Daná barva není platná",
    "The file was uploaded" : "Soubor byl nahrán",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Velikost nahrávaného souboru překračuje nastavení MAX_FILE_SIZE, která byla zadána v HTML formuláři",
    "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
    "No file was uploaded" : "Nebyl nahrán žádný soubor",
    "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
    "Could not write file to disk" : "Soubor se nedaří zapsat na datové úložiště",
    "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
    "No file uploaded" : "Nenahrán žádný soubor",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
    "Theming" : "Motiv vzhledu",
    "Appearance and accessibility" : "Vzhled a zpřístupnění",
    "Dark theme with high contrast mode" : "Tmavý motiv vzhledu s režimem vysokého kontrastu",
    "Enable dark high contrast mode" : "Používat tmavý režim s vysokým kontrastem",
    "Similar to the high contrast mode, but with dark colours." : "Podobné režimu s vysokým kontrastem, ale s tmavými barvami.",
    "Dark theme" : "Tmavý motiv vzhledu",
    "Enable dark theme" : "Používat tmavý motiv vzhledu",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Tmavý motiv vzhledu pro ulevení vašim očím pomocí omezení celkové svítivosti a jasu.",
    "System default theme" : "Výchozí systémový vzhled",
    "Enable the system default" : "Použít systémový výchozí",
    "Using the default system appearance." : "Používá se výchozí systémový vzhled.",
    "Dyslexia font" : "Písmo pro dyslektiky",
    "Enable dyslexia font" : "Používat písmo pro dyslektiky",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je bezplatné písmo (font) navržené tak, aby odpomáhalo od některých běžných chybování při čtení, způsobených dyslexií.",
    "High contrast mode" : "Režim s vysokým kontrastem",
    "Enable high contrast mode" : "Zapnout režim s vysokým kontrastem",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Režim s vysokým kontrastem pro usnadnění orientace při pohybu po aplikaci. Vizuální kvalita bude snížena, zato zřetelnost se zlepší.",
    "Light theme" : "Světlý motiv vzhledu",
    "Enable the default light theme" : "Používat výchozí světlý vzhled",
    "The default light appearance." : "Výchozí světlý vzhled.",
    "Legal notice" : "Právní upozornění",
    "Privacy policy" : "Zásady ochrany soukromí",
    "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Přístupnost pro všechny je pro nás velmi důležitá. Splňujeme webové standardy a zajišťujeme, aby všechno bylo použitelné i bez myši a s asistenčním software, jako například čtečkami obrazovky. Máme za cíl být v souladu s doporučeními {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na úrovni AA, při použití motivu vzhledu s vysokým kontrastem dokonce na úrovni AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Pokud naleznete jakékoli problémy, neváhejte s jejich nahlášením do {issuetracker}našeho systému pro správu hlášení{linkend}. A pokud se chcete zapojit, přidejte se k {designteam}týmu našich designérů{linkend}!",
    "Theme selection is enforced" : "Výběr motivu vzhledu je vynucen",
    "Open documentation" : "Otevřít dokumentaci",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduše přizpůsobit vzhled a dojem z vaší instance a podporovaných klientů. Projeví se všem uživatelům.",
    "Name" : "Název",
    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
    "Web link" : "Webový odkaz",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Barva",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrát nové logo",
    "Login image" : "Přihlašovací obrázek",
    "Upload new login background" : "Nahrát nové pozadí pro přihlašovací obrazovku",
    "Remove background image" : "Odebrat obrázek z pozadí",
    "Advanced options" : "Pokročilé předvolby",
    "Legal notice link" : "Odkaz na právní upozornění",
    "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
    "Header logo" : "Logo pro záhlaví",
    "Upload new header logo" : "Nahrát nové logo pro záhlaví",
    "Favicon" : "ikona webu",
    "Upload new favicon" : "Nahrát novou ikonu webu",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky vytváří favicon na základě nahraného loga a barvy."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
